VirtualKeyboardController class

Inheritance
Available extensions

Constructors

VirtualKeyboardController({required TextEditingController textEditingController, ScrollController? scrollController})

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
isCapsOn → bool
no setter
isShiftPressed → bool
no setter
keys → List<List<VirtualKeyboardKey>>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollController → ScrollController?
final
textEditingController → TextEditingController
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
changeKeyboard() → void
dispose() → void
Discards any resources used by the object.
inherited
getFormattedDisplayValue(String displayValue) → String
getFormattedKeyValue(String value) → String
handleKeyTap(VirtualKeyboardKey key) → void

Available on VirtualKeyboardController, provided by the VirtualKeyboardActionHandler extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
resetShift() → void
toggleCaps() → void
toggleShift() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited