VirtualKeyboardStyle class

Constructors

VirtualKeyboardStyle({Color? backgroundColor, TextStyle? keysTextStyle, Color? keyColor, Color? keyPressedColor, Color? keyHoverColor, BoxDecoration? keyDecorations, BoxDecoration? keyboardDecorations})

Properties

backgroundColor → Color
no setter
hashCode → int
The hash code for this object.
no setterinherited
keyboardDecorations → BoxDecoration?
no setter
keyColor → Color
no setter
keyDecorations → BoxDecoration?
no setter
keyHoverColor → Color
no setter
keyPressedColor → Color
no setter
keysTextStyle → TextStyle
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBuildContext(BuildContext context) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited