buildCounter property
Builds the widget to show under the input for the current character/word count.
Implementation
final InputCounterWidgetBuilder? buildCounter;
Builds the widget to show under the input for the current character/word count.
final InputCounterWidgetBuilder? buildCounter;