textCapitalization property
Configures how the platform keyboard will select an uppercase or lowercase keyboard.
Implementation
final TextCapitalization textCapitalization;
Configures how the platform keyboard will select an uppercase or lowercase keyboard.
final TextCapitalization textCapitalization;